package org.example.missocios;

import android.app.Activity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.support.v7.app.ActionBarActivity;
import android.support.v7.app.AlertDialog;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import java.io.File;
import java.io.FileNotFoundException;
import java.sql.Date;
import java.text.DateFormat;

public class VistaFichaSocio extends ActionBarActivity {
    private long id;
    private Socio socio;
    private ImageView imageView;
    final static int RESULTADO_EDITAR = 1;
    final static int RESULTADO_GALERIA = 2;
    final static int RESULTADO_FOTO = 3;
    private Uri uriFoto;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.vista_ficha_socio);
        Bundle extras = getIntent().getExtras();
        id = extras.getLong("id", -1);
        socio = Socios.elemento((int) id);
        imageView = (ImageView) findViewById(R.id.foto);
        actualizarvistas();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.vista_ficha, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.accion_compartir:
                Intent intent = new Intent(Intent.ACTION_SEND);
                intent.setType("text/plain");
                intent.putExtra(Intent.EXTRA_TEXT,
                        socio.getNombre()  + " - " +socio.getPrimer_Apellido() + " - " + socio.getEmail());
                startActivity(intent);
                return true;
            case R.id.accion_editar:
                Intent i = new Intent(VistaFichaSocio.this, EdicionFichaSocio.class);
                i.putExtra("id", id);
                startActivityForResult(i, RESULTADO_EDITAR);
                return true;
            case R.id.accion_borrar:
                new AlertDialog.Builder(this)
                        .setTitle("Borrado de Socio")
                        .setMessage("¿Estas seguro de eliminar ha este socio?")
                        .setPositiveButton("Confirmar", new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int whichButton) {
                                Socios.borrar((int) id);
                                finish();
                            }
                        })
                        .setNegativeButton("Cancelar", null)
                        .show();


                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    public void actualizarvistas() {
        socio = Socios.elemento((int) id);
        TextView nombre = (TextView) findViewById(R.id.nombre);
        nombre.setText(socio.getNombre());
        TextView PrimerApellido = (TextView) findViewById(R.id.PrimerApellido);
        PrimerApellido.setText(socio.getPrimer_Apellido());
        TextView SegundoApellido = (TextView) findViewById(R.id.SegundoApellido);
        SegundoApellido.setText(socio.getSegundo_Apellido());
        TextView dni = (TextView) findViewById(R.id.DNI);
        dni.setText(Integer.toString(socio.getDNI()));
        TextView NumeroSocio = (TextView) findViewById(R.id.NumeroSocio);
        NumeroSocio.setText(Integer.toString(socio.getNumero_socio()));

        ImageView logo_tipoSocio = (ImageView) findViewById(R.id.logo_TipoSocio);
        logo_tipoSocio.setImageResource(socio.getTipoSocio().getRecurso());
        TextView tipoSocio = (TextView) findViewById(R.id.TipoSocio);
        tipoSocio.setText(socio.getTipoSocio().getTexto());

        TextView direccion = (TextView) findViewById(R.id.direccion);
        direccion.setText(socio.getDireccion());
        TextView telefono = (TextView) findViewById(R.id.telefono);
        telefono.setText(Integer.toString(socio.getTelefono()));
        TextView email = (TextView) findViewById(R.id.Email);
        email.setText(socio.getEmail());

        ImageView logo_Servicios = (ImageView) findViewById(R.id.logo_Servicio);
        logo_Servicios.setImageResource(socio.getServicios().getRecurso());
        TextView servicios = (TextView) findViewById(R.id.Servicios);
        servicios.setText(socio.getServicios().getTexto());

        TextView cuota = (TextView) findViewById(R.id.Cuota);
        cuota.setText(Integer.toString(socio.getCuota()));

        TextView fecha = (TextView) findViewById(R.id.fecha);
        fecha.setText(DateFormat.getDateInstance().format(
                new Date(socio.getFecha())));
        TextView hora = (TextView) findViewById(R.id.hora);
        hora.setText(DateFormat.getTimeInstance().format(
                new Date(socio.getFecha())));

        TextView historial = (TextView) findViewById(R.id.historial);
        historial.setText(socio.getHistorial());
        ponerFoto(imageView, socio.getFoto());
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == RESULTADO_EDITAR) {
            actualizarvistas();
            findViewById(R.id.scrollView1).invalidate();
        } else if (requestCode == RESULTADO_GALERIA
                && resultCode == Activity.RESULT_OK) {
            socio.setFoto(data.getDataString());
            Socios.actualizaSocio((int) id, socio);
            ponerFoto(imageView, socio.getFoto());
        }else if (requestCode == RESULTADO_FOTO && resultCode == Activity.RESULT_OK
                && socio!=null && uriFoto!=null) {
            socio.setFoto(uriFoto.toString());
            Socios.actualizaSocio((int) id, socio);
            ponerFoto(imageView, socio.getFoto());
        }
    }

    protected void ponerFoto(ImageView imageView, String uri) {
        if (uri != null) {
            imageView.setImageBitmap(reduceBitmap(this, uri, 1024, 1024));
        } else {
            imageView.setImageBitmap(null);
        }
    }
    public static Bitmap reduceBitmap(Context contexto, String uri,
                                      int maxAncho, int maxAlto) {
        try {
            final BitmapFactory.Options options = new BitmapFactory.Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeStream(contexto.getContentResolver()
                    .openInputStream(Uri.parse(uri)), null, options);
            options.inSampleSize = (int) Math.max(
                    Math.ceil(options.outWidth / maxAncho),
                    Math.ceil(options.outHeight / maxAlto));
            options.inJustDecodeBounds = false;
            return BitmapFactory.decodeStream(contexto.getContentResolver()
                    .openInputStream(Uri.parse(uri)), null, options);
        } catch (FileNotFoundException e) {
            Toast.makeText(contexto, "Fichero/recurso no encontrado",
                    Toast.LENGTH_LONG).show();
            e.printStackTrace();
            return null;
        }
    }
    public void galeria(View view) {
        Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
        intent.addCategory(Intent.CATEGORY_OPENABLE);
        intent.setType("image/*");
        startActivityForResult(intent, RESULTADO_GALERIA);
    }
    public void tomarFoto(View view) {
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        uriFoto = Uri.fromFile(new File( Environment.getExternalStorageDirectory() + File.separator + "img_" + (System.currentTimeMillis() / 1000) + ".jpg"));
        intent.putExtra(MediaStore.EXTRA_OUTPUT, uriFoto);
        startActivityForResult(intent, RESULTADO_FOTO);
    }
    public void eliminarFoto(View view) {
        socio.setFoto(null);
        ponerFoto(imageView, null);
        Socios.actualizaSocio((int) id, socio);
    }

    public void llamadaTelefono(View view) {
        startActivity(new Intent(Intent.ACTION_DIAL,
                Uri.parse("tel:" + socio.getTelefono())));
    }
}


